package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: May 7, 2025
License: AGPL-3.0
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Worker process page extraction
type Job struct {
Page Page
PageNum int
}
Job contains data about Page processed and current page number
type JobErr struct {
Err error
WorkerID int
}
JobErr stores error for workerID if occurs
Page contains settings for page extraction as image and pointer to source doc
Extract page from pdf document as image
Thumbnail contains settings for thimbnails
Source Files
¶
Click to show internal directories.
Click to hide internal directories.